#!/usr/bin/python
#
# use: utils/diff_helper.py|xargs bzr diff
#

from bzrlib import workingtree
from subprocess import call

wt = workingtree.WorkingTree.open('.')
changes=wt.changes_from(wt.basis_tree())

for add in changes.added:
    print add[0]

for rm in changes.removed:
    print rm[0]




#!/usr/bin/python

import glob

pkgnames_to_desktop = {}

for fname in glob.glob("menu-data/*.desktop"):
    with open(fname) as f:
        for line in f.readlines():
            line = line.strip()
            if line.startswith("X-AppInstall-Package"):
                pkgname = line.split("=")[-1]
                if not pkgname in pkgnames_to_desktop:
                    pkgnames_to_desktop[pkgname] = []
                pkgnames_to_desktop[pkgname].append(fname)

for pkgname, desktop_files in sorted(pkgnames_to_desktop.iteritems(),
                                     cmp=lambda a,b: -cmp(len(a[1]), 
                                                          len(b[1]))):
    if len(desktop_files) > 1:
        print("%s: %s" % (pkgname, desktop_files))
        



#!/usr/bin/python

import glob
import gtk
import gzip
import os
import subprocess
import sys
import urllib

def get_icon_cache(menudir):
    icons = gtk.icon_theme_get_default()
    icons.set_search_path([os.path.join(menudir, "icons"),
                           "/usr/share/icons/hicolor",
                           "/usr/share/icons/gnome",
                           ])
    return icons


if __name__ == "__main__":
    
    menudir = sys.argv[1]
    distroseries = sys.argv[2]

    icons = get_icon_cache(menudir)

    # gather what is missing
    missing = set()
    for dentry in glob.glob("%s/*.desktop" % menudir):
        pkgname = None
        for line in open(dentry):
            if line.startswith("Icon"):
                iconname_raw = line.strip().partition("=")[2]
                iconname = os.path.splitext(iconname_raw)[0]
                if iconname and not icons.has_icon(iconname):
                    #print "missing icon: '%s' in '%s'" % (iconname, dentry)
                    if iconname_raw.startswith("_"):
                        # convert "_" back to "/"
                        iconname_raw = iconname_raw.replace("_", "/")
                        # contents file comits the leading "/"
                        iconname_raw = iconname_raw[1:]
                    missing.add(iconname_raw)
    #print len(missing)

    # go over the missing ones using the Contents file
    contents = "Contents-i386.gz"
    subprocess.call(["wget", "-c", 
                     "http://archive.ubuntu.com/ubuntu/dists/%s/%s" % (
                distroseries, contents)])
    
    all_finds = {}
    for line in gzip.open(contents):
        (path, sep, component_section_packages) = line.strip().partition(" ")
        basename = os.path.basename(path)
        extension = os.path.splitext(basename)[1]
        if not extension in (".svg", ".png", ".xpm", ".tiff"):
            continue
        found = None
        if path in missing:
            #print "found full path '%s' in '%s'" % (path, component_section_packages)
            missing.remove(path)
            found = path
        elif basename in missing:
            #print "found basename '%s' in '%s'" % (path, component_section_packages)       
            missing.remove(basename)
            found = basename
        elif os.path.splitext(basename)[0] in missing:
            #print "found basename with no extension '%s' in '%s'" % (path, component_section_packages)
            missing.remove(os.path.splitext(basename)[0])
            found = os.path.splitext(basename)[0]
        if found:
            pkgname = os.path.basename(component_section_packages)
            if "icon-theme" in pkgname:
                continue
            if not pkgname in all_finds:
                all_finds[pkgname] = []
            all_finds[pkgname].append(found)

    print "pkgname -> icons"
    print all_finds



#!/usr/bin/env python
# (c) 2005-2007 Canonical, GPL
# Authors:
#  Michael Vogt


import os
import sys
import string
import glob
import urllib
from optparse import OptionParser

def extractKeywordsData(keywords_file):
    keywords_dict = {}
    for line in map(string.strip, open(keywords_file)):
        (pkgname, keywords) = line.split(":")
        keywords_dict[pkgname] = keywords
    return keywords_dict

def mergeKeywordsData(menudir, keyword_data):
    for dentry in glob.glob("%s/*.desktop" % menudir):
        pkgname = None
        for line in open(dentry):
            if line.startswith("X-AppInstall-Package"):
                pkgname = line.strip().split("=")[1]
                if not keyword_data.has_key(pkgname):
                    pkgname = None
        if not pkgname is None:
            print "Updating '%s' with keyword data for '%s'" % (dentry,pkgname)
            content = []
            for line in open(dentry):
                if not line.startswith("X-AppInstall-Keywords="):
                    content.append(line)
                if line.startswith("X-AppInstall-Package"):
                    content.append("X-AppInstall-Keywords=%s\n" % keyword_data[pkgname])
            if not content[-1].endswith("\n"):
                content[-1] += "\n"
            f = open(dentry,"w")
            f.write("".join(content))
            f.close()

if __name__ == "__main__":
    parser = OptionParser()
    parser.add_option("-v", "--verbose", dest="verbose",
                      action="store_true", default="False",
                      help="be verbose")
    parser.add_option("-d", "--direcroty", dest="dir",
                      default="./menu-data",
                      help="directory for the menu-data")
    (options, args) = parser.parse_args()

    # filename
    keywords_file = "keywords.def"

    # extract the data, keywords_data is a dictionary with
    # (pkgname -> value) 
    keywords_data = extractKeywordsData(keywords_file)

    # merge popcon data
    mergeKeywordsData(options.dir, keywords_data)
    

    
